@@ -35,42 +35,69 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: mmap.c,v 1.3 2001/02/14 00:20:52 masayu-a Exp $
+ * $Id: mmap.c,v 1.7 2001/03/16 06:13:57 kazuma-t Exp $
  */
 
 #include "config.h"
-#if defined _WIN32 && ! defined __CYGWIN__
-#include <io.h>
-#include <process.h>
-#else
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
-#endif /* _WIN32 && ! defined __CYGWIN__ */
-#include <sys/types.h>
+#endif
+#ifdef HAVE_FCNTL_H
+#include <fcntl.h>
+#endif
+#ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
+#endif
+#ifdef HAVE_SYS_TYPES_H
+#include <sys/types.h>
+#endif
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
+#ifdef HAVE_IO_H
+#include <io.h>
+#endif
+#ifdef HAVE_PROCESS_H
+#include <process.h>
+#endif
+#ifdef HAVE_WINSOCK2_H
+#include <winsock2.h>
+#endif
+
+#ifdef __MINGW32__
+#undef HAVE_MMAP
+#endif
 #ifdef HAVE_MMAP
 #include <sys/mman.h>
 #endif
-#include "chadic.h"
 
 #if ! defined _WIN32 && ! defined __CYGWIN__
 #define O_BINARY 0
 #endif
 
-off_t cha_mmap_file(char *filename, void **map)
+#include "chadic.h"
+
+static off_t
+mmap_file(char *filename, void **map, int prot)
 {
     int fd;
+    int flag = O_RDONLY;
     struct stat st;
     off_t size;
 
-    if ((fd = open(filename, O_RDONLY)) < 0)
-        cha_exit_perror(filename);
+    if ((prot & PROT_WRITE) != 0)
+	flag = O_RDWR;
+	
+    if ((fd = open(filename, flag)) < 0)
+	cha_exit_perror(filename);
     if (fstat(fd, &st) < 0)
-        cha_exit_perror(filename);
+	cha_exit_perror(filename);
     size = st.st_size;
 #ifdef HAVE_MMAP
-    if ((*map = mmap((void *)0, size, PROT_READ, MAP_SHARED, fd, 0))
-        == MAP_FAILED ) {
-        cha_exit_perror(filename);
+    if ((*map = mmap((void *) 0, size, prot, MAP_SHARED, fd, 0))
+	== MAP_FAILED) {
+	cha_exit_perror(filename);
     }
 #else
     *map = cha_malloc(size);
@@ -82,7 +109,20 @@ off_t cha_mmap_file(char *filename, void **map)
     return size;
 }
 
-void cha_munmap_file(void *map, off_t size)
+off_t
+cha_mmap_file(char *filename, void **map)
+{
+    return mmap_file(filename, map, PROT_READ);
+}
+
+off_t
+cha_mmap_file_w(char *filename, void **map)
+{
+    return mmap_file(filename, map, PROT_READ | PROT_WRITE);
+}
+
+void
+cha_munmap_file(void *map, off_t size)
 {
 #ifdef HAVE_MMAP
     munmap(map, size);
